==> bing_indexing_api-1.0.2.tar.gz: bing_indexing_api/src/Service/BingIndexingApi.php <==
<?php

declare(strict_types=1);

namespace Drupal\bing_indexing_api\Service;

use Drupal\Component\Serialization\Json;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use Psr\Http\Message\ResponseInterface;
use Psr\Log\LoggerInterface;

/**
 * Provides the reindexing URL request to Bing Webmaster Tools.
 */
class BingIndexingApi implements BingIndexingApiInterface {

  use StringTranslationTrait;

  /**
   * The Bing Indexing API endpoint.
   */
  const ENDPOINT = 'https://www.bing.com/webmaster/api.svc/json/SubmitUrlbatch?apikey=';

  /**
   * Constructs BingIndexingApi.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The State Service.
   * @param \Psr\Log\LoggerInterface $logger
   *   The Logging Service.
   * @param \GuzzleHttp\ClientInterface $client
   *   Http Client.
   */
  public function __construct(protected StateInterface $state, protected LoggerInterface $logger, protected ClientInterface $client) {
  }

  /**
   * {@inheritdoc}
   */
  public function reindexUrl(string|array $urls): array {
    $urls = is_string($urls) ? [$urls] : $urls;

    if ($response = $this->callApi($urls)) {
      $status_code = $response->getStatusCode();

      if ($success = $status_code === 200) {
        $message = $this->t('Bing Indexing API: successfully triggered URL reindexing for: @url.', ['@url' => implode(', ', $urls)]);
        $this->logger->notice($message);
      }
      else {
        $body = Json::decode($response->getBody()->getContents());
        $body = is_array($body) ? $body : [];
        $this->logger->error($this->t('The Bing Index API returned a status code of @status_code for @url. Response message: @message', [
          '@status_code' => $status_code,
          '@url' => implode(', ', $urls),
          '@message' => $body['error']['message'] ?? '',
        ]));
      }
    }

    return [
      'success' => $success ?? FALSE,
      'message' => $message ?? $this->t('A problem occurred during URL reindexing: @url', ['@url' => implode(', ', $urls)]),
    ];
  }

  /**
   * Requests URLs reindexing in Bing Webmaster Tools.
   *
   * @param array $urls
   *   The URLs to be reindexed in Bing Webmaster Tools.
   *
   * @return \Psr\Http\Message\ResponseInterface|null
   *   API response if successful or NULL
   */
  public function callApi(array $urls): ?ResponseInterface {
    if (empty($urls)) {
      return NULL;
    }
    $base_domain = $this->state->get('bing_index_api_base_domain');
    $api_key = $this->state->get('bing_index_api_key');

    if (!$base_domain || !$api_key) {
      $this->logger->error($this->t('Check the Bing API settings: the domain or API key is missing.'));
      return NULL;
    }

    try {
      return $this->client->request('POST', self::ENDPOINT . $api_key, [
        'json' => [
          'siteUrl' => $base_domain,
          'urlList' => $urls,
        ],
        'headers' => [
          'Content-type' => 'application/json; charset=utf-8',
        ],
      ]);
    }
    catch (\Exception | GuzzleException $exception) {
      $this->logger->error($exception->getMessage());
    }

    return NULL;
  }

}

==> bing_indexing_api-1.0.3.tar.gz: bing_indexing_api/src/Service/BingIndexingApi.php <==
<?php

declare(strict_types=1);

namespace Drupal\bing_indexing_api\Service;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use Psr\Http\Message\ResponseInterface;
use Psr\Log\LoggerInterface;

/**
 * Provides the reindexing URL request to Bing Webmaster Tools.
 */
class BingIndexingApi implements BingIndexingApiInterface {

  use StringTranslationTrait;

  /**
   * The Bing Indexing API endpoint.
   */
  const ENDPOINT = 'https://www.bing.com/webmaster/api.svc/json/SubmitUrlbatch?apikey=';

  /**
   * Constructs BingIndexingApi.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   The State Service.
   * @param \Psr\Log\LoggerInterface $logger
   *   The Logging Service.
   * @param \GuzzleHttp\ClientInterface $client
   *   Http Client.
   */
  public function __construct(protected ConfigFactoryInterface $config, protected LoggerInterface $logger, protected ClientInterface $client) {
  }

  /**
   * {@inheritdoc}
   */
  public function reindexUrl(string|array $urls): array {
    $urls = is_string($urls) ? [$urls] : $urls;

    if ($response = $this->callApi($urls)) {
      $status_code = $response->getStatusCode();

      if ($success = $status_code === 200) {
        $message = $this->t('Bing Indexing API: successfully triggered URL reindexing for: @url.', ['@url' => implode(', ', $urls)]);
        $this->logger->notice($message);
      }
      else {
        $body = Json::decode($response->getBody()->getContents());
        $body = is_array($body) ? $body : [];
        $this->logger->error($this->t('The Bing Index API returned a status code of @status_code for @url. Response message: @message', [
          '@status_code' => $status_code,
          '@url' => implode(', ', $urls),
          '@message' => $body['error']['message'] ?? '',
        ]));
      }
    }

    return [
      'success' => $success ?? FALSE,
      'message' => $message ?? $this->t('A problem occurred during URL reindexing: @url', ['@url' => implode(', ', $urls)]),
    ];
  }

  /**
   * Requests URLs reindexing in Bing Webmaster Tools.
   *
   * @param array $urls
   *   The URLs to be reindexed in Bing Webmaster Tools.
   *
   * @return \Psr\Http\Message\ResponseInterface|null
   *   API response if successful or NULL
   */
  public function callApi(array $urls): ?ResponseInterface {
    if (empty($urls)) {
      return NULL;
    }
    $config = $this->config->get('bing_indexing_api.credentials');
    $base_domain = $config->get('base_domain');
    $api_key = $config->get('api_key');

    if (!$base_domain || !$api_key) {
      $this->logger->error($this->t('Check the Bing API settings: the domain or API key is missing.'));
      return NULL;
    }

    try {
      return $this->client->request('POST', self::ENDPOINT . $api_key, [
        'json' => [
          'siteUrl' => $base_domain,
          'urlList' => $urls,
        ],
        'headers' => [
          'Content-type' => 'application/json; charset=utf-8',
        ],
      ]);
    }
    catch (\Exception | GuzzleException $exception) {
      $this->logger->error($exception->getMessage());
    }

    return NULL;
  }

}
